import { select, 
        csv, 
        scaleLinear, 
        max, 
        scaleBand, 
        axisLeft,
        axisBottom,
        mouse,
       } from "d3";

const svg = select("svg");

const width = +svg.attr("width");
const height = +svg.attr("height");

const render = data => {
	const xValue = d => d.Date;
  const yValue = d => d.Confirmed;
  const margin = { top: 50, right: 20, bottom: 70, left: 70 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const yScale = scaleLinear()
  	.domain([max(data,yValue),0])
  	.range([0, innerHeight]);
  
  const xScale = scaleBand()
  	.domain(data.map(xValue))
    .range([0, innerWidth])
  	.padding(0.15);
  
 const g = svg.append('g')
  	.attr('transform', `translate(${margin.left},${margin.top})`);
  
  g.append('g').call(axisLeft(yScale))
  .selectAll("text")
  .style("font-family",'IBM Plex Mono')
  .attr("font-weight",900);
  
   g.append('g').call(axisBottom(xScale))
  .attr('transform', `translate(0,${innerHeight})`)
  .selectAll("text")
  .attr("transform", "translate(-10,10)rotate(-45)")
  .style("font-family",'IBM Plex Mono')
  .attr("font-weight",900)
  .attr("x", innerWidth-884)
  ;
  
   g.append("text")
    .attr("text-anchor", "end")
    .attr("x", innerWidth-860)
    .attr("y", innerHeight + margin.top + 8)
    .text("Date")
  	.style("font-family",'IBM Plex Sans')
  	.attr("font-weight",900);
  
   g.append("text")
    .attr("text-anchor", "end")
    .attr("transform", "rotate(-90)")
    .attr("y", -margin.left+25)
    .attr("x", -margin.top-80)
    .text("Number of Confirmed Cases")
  	.style("font-family",'IBM Plex Sans')
  	.attr("font-weight",900);
  
  g.selectAll("rect")
    .data(data)
  	.enter()
    .append("rect")
  	.attr("x", d => xScale(xValue(d)))
  	.attr("width", xScale.bandwidth())
    .attr('y', function(d) { return yScale(d.Confirmed); } )
    .attr('height', function(d,i){ return height - yScale(d.Confirmed)-margin.top-margin.bottom})
  	.on('mouseover', tip.show)
    .on('mouseout', tip.hide)
};

var tip = d3.tip()
  .attr('class', 'd3-tip')
  .offset([-10, 0])
  .html(function(d) {
    return "<strong>Date:</strong> <span style='color:orange'>" +d.Date + "</span> </b></span><br> <strong>Cases:</strong> <span style='color:orange'>" + d.Confirmed + "</span>"
  })
	.style("font-family",'IBM Plex Sans')
  .attr("font-weight",900);


svg.call(tip);

csv("data.csv").then(data => {
  data.forEach(d => {
    d.Confirmed = +d.Confirmed;
  });
  render(data);
});